@@ -25,6 +25,7 @@ and http://janne-pekkala.blogspot.com/"""
     p.author="Janne Pekkala"
     p.maintainer="Yabba"
     p.mail="yabbapappa@gmail.com"
+    p.url="http://janne-pekkala.blogspot.com"
     p.depends = "python2.5, python2.5-qt4-gui, python2.5-qt4-core, python-osso, python-gst0.10, lirc"
     p.section="user/utilities"
     p.icon = "/home/user/MyDocs/pykake/pykake.png"
@@ -38,7 +39,6 @@ and http://janne-pekkala.blogspot.com/"""
     p.postinstall="""#!/bin/sh
     chmod -x /opt/pykake/pykake.py
     chmod -R a=rx /opt/pykake/
-    gconftool-2 --recursive-unset /apps/Maemo/pykake # Till next major update (0.8.0), removing needles gtk stuff from registry
     sed -i \'/pyKake/ d\' /etc/lircd.conf
     sed -i \'/pykake/ d\' /etc/lircd.conf
     echo "# Lirc configure files for pyKake" >> /etc/lircd.conf
@@ -54,18 +54,17 @@ and http://janne-pekkala.blogspot.com/"""
     # Post remove script
     p.postremove="""#!/bin/sh
     sed -i \'/pyKake/ d\' /etc/lircd.conf
-    sed -i \'/pykake/ d\' /etc/lircd.conf
-    rm -r /home/user/.config/PyKake"""
+    sed -i \'/pykake/ d\' /etc/lircd.conf"""
     # sudo /etc/init.d/lirc reload """
     # p.preinstall="""#!/bin/sh
     # chmod +x /usr/bin/mclock.py""" #Set here your pre install script
     # p.preremove="""#!/bin/sh
     # chmod +x /usr/bin/mclock.py""" #Set here your pre remove script
     version = "0.7.0"           #Version of your software, e.g. "1.2.0" or "0.8.2"
-    build = "1"                 #Build number, e.g. "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
+    build = "2"                 #Build number, e.g. "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
 
     # Text with changelog information to be displayed in the package "Details" tab of the Maemo Application Manager
-    changeloginformation = """ New GUI written in Qt, code simplifying (to Qt), new function to take timelapse photos and offical support for Samsung. """
+    changeloginformation = """ New GUI written in Qt, code simplifying (to Qt), new function to take timelapse photos and offical support for Samsung. Bugfix for postinstall script. """
 
     dir_name = "src"            #Name of the subfolder containing your package source files (e.g. usr\share\icons\hicolor\scalable\myappicon.svg, usr\lib\myapp\somelib.py). We suggest to leave it named src in all projects and will refer to that in the wiki article on maemo.org
     #Thanks to DareTheHair from talk.maemo.org for this snippet that recursively builds the file list
